@@ -1,7 +1,7 @@
 # StateIncome.pm
 # Created:  Thu Feb 14 15:30:24 CST 2002
 # by Xperience, Inc. (mailto:admin@pcxperience.com)
-# $Id: StateIncome.pm,v 1.14 2005/01/15 19:26:38 moreejt Exp $
+# $Id: StateIncome.pm,v 1.17 2005/12/30 15:11:01 moreejt Exp $
 # Copyright (c) 2002-2003 http://www.pcxperience.org  All rights reserved.
 # license: same as perl
 
@@ -38,6 +38,8 @@ $VERSION = '0.3';
 
 =head1 Exported FUNCTIONS
 
+=over 4
+
 =head2  scalar new()
 
         Creates a new instance of the object.
@@ -69,7 +71,6 @@ sub new
         daily => 260
      };
 
-    $self->{debug} = "yes";
     $self->{dataTables} =  {
             '19990101' => {
                standardDeduction => {single => '4300', married => '3600' , spouseWorks => '3600', head => '3600' },
@@ -176,6 +177,27 @@ sub new
                     {bottom => '9000.01', percent => '0.06' }
                 ]
             },
+            '20060101' => {
+               standardDeduction => {single => '5150', married => '10300' , spouseWorks => '5150', head => '7550' },
+               allowance1 => { single => '1200', married => '1200' , spouseWorks => '1200', head => '3500'},
+               allowance2 => { single => '1200', married => '1200' , spouseWorks => '1200', head => '1200'},
+               allowance3 => { single => '1200', married => '1200' , spouseWorks => '1200', head => '1200'},
+               allowance4 => { single => '1200', married => '1200' , spouseWorks => '1200', head => '1200'},
+               allowance5 => { single => '1200', married => '1200' , spouseWorks => '1200', head => '1200'},
+               federalLimit => { single => '5000', married => '10000' , spouseWorks => '5000' },
+               percentTable => [
+                    {bottom => '0', percent => '.015' },
+                    {bottom => '1000.01', percent => '0.02' },
+                    {bottom => '2000.01', percent => '0.025' },
+                    {bottom => '3000.01', percent => '0.03' },
+                    {bottom => '4000.01', percent => '0.035' },
+                    {bottom => '5000.01', percent => '0.04' },
+                    {bottom => '6000.01', percent => '0.045' },
+                    {bottom => '7000.01', percent => '0.05' },
+                    {bottom => '8000.01', percent => '0.055' },
+                    {bottom => '9000.01', percent => '0.06' }
+                ]
+            },
         };
 
   return $self;
